@@ -469,6 +469,10 @@ int root_command_string( irc_t *irc, user_t *u, char *command, int flags )
 				cmd[k++] = s;
 				s --;
 			}
+			else
+			{
+				break;
+			}
 		}
 		else if( *s == q )
 		{
