@@ -134,7 +134,7 @@ irc_t *irc_new( int fd )
 	return( irc );
 }
 
-static gboolean irc_free_userhash( gpointer key, gpointer value, gpointer data )
+static gboolean irc_free_hashkey( gpointer key, gpointer value, gpointer data )
 {
 	g_free( key );
 	
@@ -218,10 +218,10 @@ void irc_free(irc_t * irc)
 		}
 	}
 	
-	g_hash_table_foreach_remove(irc->userhash, irc_free_userhash, NULL);
+	g_hash_table_foreach_remove(irc->userhash, irc_free_hashkey, NULL);
 	g_hash_table_destroy(irc->userhash);
 	
-	g_hash_table_foreach_remove(irc->watches, irc_free_userhash, NULL);
+	g_hash_table_foreach_remove(irc->watches, irc_free_hashkey, NULL);
 	g_hash_table_destroy(irc->watches);
 	
 	if (irc->nicks != NULL) {
@@ -577,7 +577,7 @@ int irc_exec( irc_t *irc, char **cmd )
 					
 					if( !u->gc->prpl->chat_open( u->gc, u->handle ) )
 					{
-						irc_usermsg( irc, "Could not open a groupchat with %s, maybe you don't have a connection to him/her yet?", u->nick );
+						irc_usermsg( irc, "Could not open a groupchat with %s.", u->nick );
 					}
 				}
 				else
@@ -684,7 +684,7 @@ int irc_exec( irc_t *irc, char **cmd )
 	{
 		user_t *u;
 		char buff[IRC_MAX_LINE];
-		int lenleft;
+		int lenleft, i;
 		
 		buff[0] = '\0';
 		
@@ -693,36 +693,44 @@ int irc_exec( irc_t *irc, char **cmd )
 		
 		for( i = 1; cmd[i]; i ++ )
 		{
-			if( ( u = user_find( irc, cmd[i] ) ) && u->online )
+			char *this, *next;
+			
+			this = cmd[i];
+			while( *this )
 			{
-				/* [SH] Make sure we don't use too much buffer space. */
-				lenleft -= strlen( u->nick ) + 1;
+				if( ( next = strchr( this, ' ' ) ) )
+					*next = 0;
 				
-				if( lenleft < 0 )
+				if( ( u = user_find( irc, this ) ) && u->online )
 				{
-					break;
+					lenleft -= strlen( u->nick ) + 1;
+					
+					if( lenleft < 0 )
+						break;
+					
+					strcat( buff, u->nick );
+					strcat( buff, " " );
 				}
 				
-				/* [SH] Add the nick to the buffer. Note
-				 * that an extra space is always added. Even
-				 * if it's the last nick in the list. Who
-				 * cares?
-				 */
-				
-				strcat( buff, u->nick );
-				strcat( buff, " " );
+				if( next )
+				{
+					*next = ' ';
+					this = next + 1;
+				}
+				else
+				{
+					break;
+				}    
 			}
+			
+			/* *sigh* */
+			if( lenleft < 0 )
+				break;
 		}
 		
-		/* [WvG] Well, maybe someone cares, so why not remove it? */
 		if( strlen( buff ) > 0 )
 			buff[strlen(buff)-1] = '\0';
 		
-		/* [SH] By the way, that really *was* WvG talking. */
-		/* [WvG] Really? */
-		/* [SH] Yeah... But *this* is WvG talking too. ;-P */
-		/* [WvG] *sigh* */
-		
 		irc_reply( irc, 303, ":%s", buff );
 	}
 	else if( g_strcasecmp( cmd[0], "WATCH" ) == 0 )
@@ -876,7 +884,7 @@ int irc_usermsg( irc_t *irc, char *format, ... )
 	user_t *u;
 	
 	u = user_find( irc, irc->mynick );
-	if( u ) is_private = u->is_private;
+	is_private = u->is_private;
 	
 	va_start( params, format );
 	g_vsnprintf( text, sizeof( text ), format, params );
