@@ -32,13 +32,6 @@
 #define IRC_LOGIN_TIMEOUT 60
 #define IRC_PING_STRING "PinglBee"
 
-/* #define FLOOD_SEND 
- * Not yet enabled by default due to some problems.
- */
-#define FLOOD_SEND_INTERVAL 30
-#define FLOOD_SEND_BYTES (1024*10)
-#define FLOOD_SEND_MAXBUFFER (1024*20)
-
 #define UMODES "ais"
 #define CMODES "nt"
 #define CMODE "t"
@@ -117,7 +110,7 @@ int irc_process_line( irc_t *irc, char *line );
 
 void irc_vawrite( irc_t *irc, char *format, va_list params );
 void irc_write( irc_t *irc, char *format, ... );
-void irc_write_all( char *format, ... );
+void irc_write_all( int now, char *format, ... );
 void irc_reply( irc_t *irc, int code, char *format, ... );
 G_MODULE_EXPORT int irc_usermsg( irc_t *irc, char *format, ... );
 char **irc_tokenize( char *buffer );
@@ -137,11 +130,11 @@ void irc_invite( irc_t *irc, char *nick, char *channel );
 void irc_whois( irc_t *irc, char *nick );
 int irc_away( irc_t *irc, char *away );
 
-int irc_send( irc_t *irc, char *nick, char *s );
+int irc_send( irc_t *irc, char *nick, char *s, int flags );
 int irc_privmsg( irc_t *irc, user_t *u, char *type, char *to, char *prefix, char *msg );
 int irc_msgfrom( irc_t *irc, char *nick, char *msg );
 int irc_noticefrom( irc_t *irc, char *nick, char *msg );
 
-int buddy_send_handler( irc_t *irc, user_t *u, char *msg );
+int buddy_send_handler( irc_t *irc, user_t *u, char *msg, int flags );
 
 #endif
