@@ -1049,7 +1049,7 @@ static void jabber_accept_add(gpointer w, struct jabber_add_permit *jap)
 	 * ask if we want him or her added.
 	 */
 	if(find_buddy(GJ_GC(jap->gjc), jap->user) == NULL) {
-		show_got_added(GJ_GC(jap->gjc), NULL, jap->user, NULL, NULL);
+		show_got_added(GJ_GC(jap->gjc), jap->user, NULL);
 	}
 	g_free(jap->user);
 	g_free(jap);
@@ -1553,7 +1553,9 @@ static gboolean jabber_free(gpointer data)
 
 	if(jd->gjc != NULL) {
 		gjab_delete(jd->gjc);
+		/* YAY for modules with their own memory pool managers!...
 		g_free(jd->gjc->sid);
+		And a less sarcastic yay for valgrind. :-) */
 		jd->gjc = NULL;
 	}
 	g_free(jd);
