@@ -45,9 +45,6 @@ int msn_write( struct gaim_connection *gc, char *s, int len )
 
 int msn_logged_in( struct gaim_connection *gc )
 {
-	struct msn_data *md = gc->proto_data;
-	char buf[1024];
-	
 	account_online( gc );
 	
 	return( 0 );
@@ -133,6 +130,9 @@ static void msn_buddy_ask_yes( gpointer w, struct msn_buddy_ask_data *bla )
 {
 	msn_buddy_list_add( bla->gc, "AL", bla->handle, bla->realname );
 	
+	if( find_buddy( bla->gc, bla->handle ) == NULL )
+		show_got_added( bla->gc, bla->handle, NULL );
+	
 	g_free( bla->handle );
 	g_free( bla->realname );
 	g_free( bla );
