@@ -97,7 +97,7 @@ static int msn_ns_command( gpointer data, char **cmd, int num_parts )
 	struct msn_data *md = gc->proto_data;
 	char buf[1024];
 	
-	if( !num_parts )
+	if( num_parts == 0 )
 	{
 		/* Hrrm... Empty command...? Ignore? */
 		return( 1 );
@@ -242,7 +242,6 @@ static int msn_ns_command( gpointer data, char **cmd, int num_parts )
 			return( 0 );
 		}
 		
-		
 		md->handler->msglen = atoi( cmd[3] );
 		
 		if( md->handler->msglen <= 0 )
@@ -365,7 +364,7 @@ static int msn_ns_command( gpointer data, char **cmd, int num_parts )
 	}
 	else if( strcmp( cmd[0], "ILN" ) == 0 )
 	{
-		struct msn_away_state *st;
+		const struct msn_away_state *st;
 		
 		if( num_parts != 6 )
 		{
@@ -393,7 +392,7 @@ static int msn_ns_command( gpointer data, char **cmd, int num_parts )
 	}
 	else if( strcmp( cmd[0], "NLN" ) == 0 )
 	{
-		struct msn_away_state *st;
+		const struct msn_away_state *st;
 		
 		if( num_parts != 5 )
 		{
@@ -525,7 +524,7 @@ static int msn_ns_command( gpointer data, char **cmd, int num_parts )
 	}
 	else if( strcmp( cmd[0], "IPG" ) == 0 )
 	{
-		do_error_dialog(gc, "Received IPG command, we don't handle them yet.", "MSN" );
+		do_error_dialog( gc, "Received IPG command, we don't handle them yet.", "MSN" );
 		
 		md->handler->msglen = atoi( cmd[1] );
 		
@@ -539,7 +538,7 @@ static int msn_ns_command( gpointer data, char **cmd, int num_parts )
 	else if( isdigit( cmd[0][0] ) )
 	{
 		int num = atoi( cmd[0] );
-		struct msn_status_code *err = msn_status_by_number( num );
+		const struct msn_status_code *err = msn_status_by_number( num );
 		
 		g_snprintf( buf, sizeof( buf ), "Error reported by MSN server: %s", err->text );
 		do_error_dialog( gc, buf, "MSN" );
