@@ -438,7 +438,14 @@ void add_buddy( struct gaim_connection *gc, char *group, char *handle, char *rea
 	}
 	else if( gc->user->proto_opt[0] && *gc->user->proto_opt[0] )
 	{
-		u->host = g_strdup( gc->user->proto_opt[0] );
+		char *colon;
+		
+		if( ( colon = strchr( gc->user->proto_opt[0], ':' ) ) )
+			u->host = g_strndup( gc->user->proto_opt[0],
+			                     colon - gc->user->proto_opt[0] );
+		else
+			u->host = g_strdup( gc->user->proto_opt[0] );
+		
 		u->user = g_strdup( handle );
 		
 		/* s/ /_/ ... important for AOL screennames */
@@ -508,9 +515,40 @@ void serv_buddy_rename( struct gaim_connection *gc, char *handle, char *realname
 
 /* prpl.c */
 
-void show_got_added( struct gaim_connection *gc, char *id, char *handle, const char *realname, const char *msg )
+struct show_got_added_data
 {
-	return;
+	struct gaim_connection *gc;
+	char *handle;
+};
+
+void show_got_added_no( gpointer w, struct show_got_added_data *data )
+{
+	g_free( data->handle );
+	g_free( data );
+}
+
+void show_got_added_yes( gpointer w, struct show_got_added_data *data )
+{
+	data->gc->prpl->add_buddy( data->gc, data->handle );
+	add_buddy( data->gc, NULL, data->handle, data->handle );
+	
+	return show_got_added_no( w, data );
+}
+
+void show_got_added( struct gaim_connection *gc, char *handle, const char *realname )
+{
+	struct show_got_added_data *data = g_new0( struct show_got_added_data, 1 );
+	char *s;
+	
+	/* TODO: Make a setting for this! */
+	if( user_findhandle( gc, handle ) != NULL )
+		return;
+	
+	s = g_strdup_printf( "The user %s is not in your buddy list yet. Do you want to add him/her now?", handle );
+	
+	data->gc = gc;
+	data->handle = g_strdup( handle );
+	query_add( gc->irc, gc, s, show_got_added_yes, show_got_added_no, data );
 }
 
 
@@ -540,7 +578,8 @@ void serv_got_update( struct gaim_connection *gc, char *handle, int loggedin, in
 			
 			return;
 		}
-		return;
+		/* Why did we have this here....
+		return; */
 	}
 	
 	oa = u->away != NULL;
