@@ -135,9 +135,9 @@ static char *extract_name(const char *name) {
 	char *tmp;
 	int i, j;
 	char *x = strchr(name, '-');
-	if (!x) return NULL;
+	if (!x) return g_strdup(name);
 	x = strchr(++x, '-');
-	if (!x) return NULL;
+	if (!x) return g_strdup(name);
 	tmp = g_strdup(++x);
 
 	for (i = 0, j = 0; x[i]; i++) {
@@ -1118,7 +1118,8 @@ static void gaim_icq_authgrant(gpointer w, struct icq_auth *data) {
 	message = 0;
 	aim_ssi_auth_reply(od->sess, od->conn, uin, 1, "");
 	// aim_send_im_ch4(od->sess, uin, AIM_ICQMSG_AUTHGRANTED, &message);
-	show_got_added(data->gc, NULL, uin, NULL, NULL);
+	if(find_buddy(data->gc, uin) == NULL)
+		show_got_added(data->gc, uin, NULL);
 	
 	g_free(uin);
 	g_free(data);
@@ -2607,9 +2608,9 @@ int oscar_chat_open(struct gaim_connection * gc, char *who)
 	struct oscar_data * od = (struct oscar_data *)gc->proto_data;
 	int ret;
 	static int chat_id = 0;
-	char * chatname = g_new0(char, strlen(gc->username)+4);
+	char * chatname;
 	
-	g_snprintf(chatname, strlen(gc->username) + 4, "%s%d", gc->username, chat_id++);
+	chatname = g_strdup_printf("%s%d", gc->username, chat_id++);
   
 	ret = oscar_chat_join(gc, chatname);
 
